View source: R/reshape_mdb_df.R
| reshape_mdb_df | R Documentation |
reshape_mdb_df takes the output from make_mdb_df() and creates a gt ready data frame.
The transformed data frame retains the most recent quarter and previous year's performance.
The resulting table can be passed directly to the mdb_main_theme() to create a MDB table.
Helper functions format certain columns as svgs to be rendered in the gt call.
reshape_mdb_df(df)
df |
takes the |
returns a wide formatted data frame (table) of all OUs, countries and USAID
make_mdb_df() to see input required and
mdb_main_theme() to see the gt theme used to format the table
make_chg_shape() creates an svg based on the direction of change
make_achv_shape() creates a colored circle based on achievement level
Other data frame munging:
collapse_base_tbl(),
collapse_vlc_tbl(),
make_mdb_df(),
make_mdb_tx_df(),
reshape_mdb_tx_df()
## Not run:
mdb_df <- make_mdb_df(ou_im, resolve_issues = F)
mdb_tbl <- reshape_mdb_df(mdb_df)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.